#ifndef USB_DESCR_FS_H_
#define USB_DESCR_FS_H_
#include "uvc.h"

#ifdef INCLUDE_USB_UART
	#ifdef INCLUDE_UVC
		#define FS_CD_TOTAL_LENGTH		0x11,0x01
		#define FS_CD_NUM_INTERFACES	4
	#else
		#define FS_CD_TOTAL_LENGTH		0x43,0x00
		#define FS_CD_NUM_INTERFACES	2
	#endif
#else
	#define FS_CD_TOTAL_LENGTH		0xCE,0x00
	#define FS_CD_NUM_INTERFACES	2
#endif

#define FS_IF_NUMBER_VCI	0
#define FS_IF_NUMBER_VSI	1

#ifdef INCLUDE_UVC
	#define FS_IF_NUMBER_COMM	2
	#define FS_IF_NUMBER_DATA	3
#else
	#define FS_IF_NUMBER_COMM	0
	#define FS_IF_NUMBER_DATA	1
#endif

const uint8_t CyFxUSBFSConfigDscr[] =
    {
		// Configuration descriptor 
		0x09,                           // Descriptor size 
		CY_U3P_USB_CONFIG_DESCR,        // Configuration descriptor type 
		FS_CD_TOTAL_LENGTH,             // Length of this descriptor and all sub descriptors 
		FS_CD_NUM_INTERFACES,           // Number of interfaces 
		0x01,                           // Configuration number 
		0x03,                           // Configuration string index
		0x80,                           // Config characteristics - bus powered 
		0x64,                           // Max power consumption of device (in 2mA unit) : 200mA 
#ifdef INCLUDE_UVC
			// Interface Association Descriptor 
			0x08,                           // Descriptor Size 
			CY_FX_INTF_ASSN_DSCR_TYPE,      // Interface Association Descr Type: 11 
			FS_IF_NUMBER_VCI,               // interface number of first VideoControl interface 
			0x02,                           // Number of Video interface 
			0x0E,                           // CC_VIDEO : Video interface class code 
			0x03,                           // SC_VIDEO_INTERFACE_COLLECTION : Subclass code 
			0x00,                           // Protocol : Not used 
			0x02,                           // String desc index for interface 
			
				// Standard Video Control Interface Descriptor 
				0x09,                           // Descriptor size 
				CY_U3P_USB_INTRFC_DESCR,        // Interface Descriptor type 
				FS_IF_NUMBER_VCI,               // Interface number 
				0x00,                           // Alternate setting number 
				0x01,                           // Number of end points 
				0x0E,                           // CC_VIDEO : Interface class 
				0x01,                           // CC_VIDEOCONTROL : Interface sub class 
				0x00,                           // Interface protocol code 
				0x02,                           // Interface descriptor string index 
				
				// Class specific VC Interface Header Descriptor 
				0x0D,                           // Descriptor size 
				0x24,                           // Class Specific interface Header Descriptor type 
				0x01,                           // Descriptor Sub type : VC_HEADER 
				0x10, 0x01,                     // Revision of UVC class spec: 1.1 - Minimum version required for USB Compliance. Not supported on Windows XP
				0x51, 0x00,                     // Total Size of class specific descriptors (till Output terminal) 
				0x00,0x6C,0xDC,0x02,            // Clock frequency : 48MHz(Deprecated) 
				0x01,                           // Number of streaming interfaces 
				0x01,                           // Video streaming interface 1 belongs to VC interface 
				
				// Input (Camera) Terminal Descriptor 
				0x12,                           // Descriptor size 
				0x24,                           // Class specific interface desc type 
				0x02,                           // Input Terminal Descriptor type 
				0x01,                           // ID of this terminal 
				0x01,0x02,                      // Camera terminal type 
				0x00,                           // No association terminal 
				0x00,                           // String desc index : Not used 
				0x00,0x00,                      // No optical zoom supported 
				0x00,0x00,                      // No optical zoom supported 
				0x00,0x00,                      // No optical zoom supported 
				0x03,                           // Size of controls field for this terminal : 3 bytes 
				0x00,0x00,0x00,                 // bmControls field of camera terminal: No controls supported 
				
				// Processing Unit Descriptor 
				0x0D,                           // Descriptor size 
				0x24,                           // Class specific interface desc type 
				0x05,                           // Processing Unit Descriptor type 
				0x02,                           // ID of this terminal 
				0x01,                           // Source ID : 1 : Conencted to input terminal 
				0x00,0x40,                      // Digital multiplier 
				0x03,                           // Size of controls field for this terminal : 3 bytes 
				0x00,0x00,0x00,                 // bmControls field of processing unit: Brightness control supported 
				0x00,                           // String desc index : Not used 
				0x00,                           // Analog Video Standards Supported: None 
				
				// Extension Unit Descriptor 
				0x1C,                           // Descriptor size 
				0x24,                           // Class specific interface desc type 
				0x06,                           // Extension Unit Descriptor type 
				0x03,                           // ID of this terminal 
				0xFF,0xFF,0xFF,0xFF,            // 16 byte GUID 
				0xFF,0xFF,0xFF,0xFF,
				0xFF,0xFF,0xFF,0xFF,
				0xFF,0xFF,0xFF,0xFF,
				0x00,                           // Number of controls in this terminal 
				0x01,                           // Number of input pins in this terminal 
				0x02,                           // Source ID : 2 : Connected to Proc Unit 
				0x03,                           // Size of controls field for this terminal : 3 bytes 
				0x00,0x00,0x00,                 // No controls supported 
				0x00,                           // String desc index : Not used 
				
				// Output Terminal Descriptor 
				0x09,                           // Descriptor size 
				0x24,                           // Class specific interface desc type 
				0x03,                           // Output Terminal Descriptor type 
				0x04,                           // ID of this terminal 
				0x01,0x01,                      // USB Streaming terminal type 
				0x00,                           // No association terminal 
				0x03,                           // Source ID : 3 : Connected to Extn Unit 
				0x00,                           // String desc index : Not used 
			
					// Video Control Status Interrupt Endpoint Descriptor 
					0x07,                           // Descriptor size 
					CY_U3P_USB_ENDPNT_DESCR,        // Endpoint Descriptor Type 
					CY_FX_EP_CONTROL_STATUS,        // Endpoint address and description 
					CY_U3P_USB_EP_INTR,             // Interrupt End point Type 
					0x40,0x00,                      // Max packet size = 64 bytes 
					0x08,                           // Servicing interval : 8ms 
					
					// Class Specific Interrupt Endpoint Descriptor 
					0x05,                           // Descriptor size 
					0x25,                           // Class Specific Endpoint Descriptor Type 
					CY_U3P_USB_EP_INTR,             // End point Sub Type 
					0x40,0x00,                      // Max packet size = 64 bytes 
			
			// Standard Video Streaming Interface Descriptor (Alternate Setting 0) 
			0x09,                           // Descriptor size 
			CY_U3P_USB_INTRFC_DESCR,        // Interface Descriptor type 
			FS_IF_NUMBER_VSI,               // Interface number 
			0x00,                           // Alternate setting number 
			0x01,                           // Number of end points : Zero Bandwidth 
			0x0E,                           // Interface class : CC_VIDEO 
			0x02,                           // Interface sub class : CC_VIDEOSTREAMING 
			0x00,                           // Interface protocol code : Undefined 
			0x00,                           // Interface descriptor string index 
			
				// Class-specific Video Streaming Input Header Descriptor 
				0x0E,                           // Descriptor size 
				0x24,                           // Class-specific VS interface Type 
				0x01,                           // Descriptotor Subtype : Input Header 
				0x00,                           // No format desciptor supported for FS device 
				0x0E,0x00,                      // Total size of Class specific VS descr 
				CY_FX_EP_BULK_VIDEO,            // EP address for BULK video data 
				0x00,                           // No dynamic format change supported 
				0x04,                           // Output terminal ID : 4 
				0x01,                           // Still image capture method 1 supported 
				0x00,                           // Hardware trigger NOT supported 
				0x00,                           // Hardware to initiate still image capture NOT supported 
				0x01,                           // Size of controls field : 1 byte 
				0x00,                           // D2 : Compression quality supported 
			
					// Endpoint Descriptor for BULK Streaming Video Data 
					0x07,                           // Descriptor size 
					CY_U3P_USB_ENDPNT_DESCR,        // Endpoint Descriptor Type 
					CY_FX_EP_BULK_VIDEO,            // Endpoint address and description 
					0x02,                           // BULK End point 
					0x40,                           // EP Packet Size: 64 bytes 
					0x00,
					0x00,                            // Servicing interval for data transfers 
			
#endif
#ifdef INCLUDE_USB_UART			
			// Communication Interface descriptor 
			0x09,                           // Descriptor size 
			CY_U3P_USB_INTRFC_DESCR,        // Interface Descriptor type 
			FS_IF_NUMBER_COMM,              // Interface number 
			0x00,                           // Alternate setting number 
			0x01,                           // Number of endpoints 
			0x02,                           // Interface class: Communication interface
			0x02,                           // Interface sub class 
			0x01,                           // Interface protocol code 
			0x00,                           // Interface descriptor string index 
			
				// CDC Class-specific Descriptors 
				// Header functional Descriptor 
				0x05,                           // Descriptors length(5) 
				0x24,                           // Descriptor type : CS_Interface 
				0x00,                           // DescriptorSubType : Header Functional Descriptor 
				0x10,0x01,                      // bcdCDC : CDC Release Number 
				
				// Abstract Control Management Functional Descriptor 
				0x04,                           // Descriptors Length (4) 
				0x24,                           // bDescriptorType: CS_INTERFACE 
				0x02,                           // bDescriptorSubType: Abstract Control Model Functional Descriptor 
				0x02,                           // bmCapabilities: Supports the request combination of Set_Line_Coding, Set_Control_Line_State, Get_Line_Coding and the notification Serial_State 
				
				// Union Functional Descriptor 
				0x05,                           // Descriptors Length (5) 
				0x24,                           // bDescriptorType: CS_INTERFACE 
				0x06,                           // bDescriptorSubType: Union Functional Descriptor 
				0x00,                           // bMasterInterface 
				0x01,                           // bSlaveInterface 
				
				// Call Management Functional Descriptor 
				0x05,                           //  Descriptors Length (5) 
				0x24,                           //  bDescriptorType: CS_INTERFACE 
				0x01,                           //  bDescriptorSubType: Call Management Functional Descriptor 
				0x00,                           //  bmCapabilities: Device sends/receives call management information only over the Communication Class Interface. 
				FS_IF_NUMBER_DATA,              //  Interface Number of Data Class interface 
		
					// Endpoint Descriptor(Interrupt) 
					0x07,                           // Descriptor size 
					CY_U3P_USB_ENDPNT_DESCR,        // Endpoint descriptor type 
					0x01,                           // Endpoint address and description 
					CY_U3P_USB_EP_INTR,             // Interrupt endpoint type 
					0x10,0x00,                      // Max packet size = 16 bytes 
					0x02,                           // Servicing interval for data transfers 
		
			// Data Interface Descriptor 
			0x09,                           // Descriptor size 
			CY_U3P_USB_INTRFC_DESCR,        // Interface Descriptor type 
			FS_IF_NUMBER_DATA,              // Interface number 
			0x00,                           // Alternate setting number 
			0x02,                           // Number of endpoints 
			0x0A,                           // Interface class: Data interface 
			0x00,                           // Interface sub class 
			0x00,                           // Interface protocol code 
			0x00,                           // Interface descriptor string index 
		
				// Endpoint Descriptor(BULK-PRODUCER) 
				0x07,                           // Descriptor size 
				CY_U3P_USB_ENDPNT_DESCR,        // Endpoint descriptor type 
				0x02,                           // Endpoint address and description 
				CY_U3P_USB_EP_BULK,             // BULK endpoint type 
				0x40,0x00,                      // Max packet size = 64 bytes 
				0x00,                           // Servicing interval for data transfers 
				
				// Endpoint Descriptor(BULK- CONSUMER) 
				0x07,                           // Descriptor size 
				CY_U3P_USB_ENDPNT_DESCR,        // Endpoint descriptor type 
				0x82,                           // Endpoint address and description 
				CY_U3P_USB_EP_BULK,             // Bulk endpoint type 
				0x40,0x00,                      // Max packet size = 64 bytes 
				0x00,                           // Servicing interval for data transfers 
#endif		
		
    };


#endif // USB_DESCR_FS_H_ 
